@@ -1,4 +1,4 @@
-"factor.scores" <-
+`factor.scores` <-
 function (object, ...) {
     UseMethod("factor.scores")
 }
